#!/bin/sh
#
# HighPoint RAID Management Software Installation Script
# Copyright 2000-2004 HighPoint Technologies, Inc. All rights reserved.
#
VERSION=1.0
SRCDIR=`(cd \`dirname $0\`; pwd)`
SRCPKG=$SRCDIR/hptcli.tar.gz

HPTSVR=hptsvr
HPTRAIDCONF=hptraidconf

#if [ -f /usr/lib/libstdc++-libc6.2-2.so.3 ]; then
#	HPTSVR=hptsvr-libc6.2
#	HPTRAID=hptraid-libc6.2
#fi

usage() {
	echo "Usage:"
	echo '     "hptcliinstall.sh -i" to install (full installation)'
	echo '     "hptcliinstall.sh -u" to uninstall'
	echo '     "hptcliinstall.sh -s" to install RAID management service only'
	echo '     "hptcliinstall.sh -g" to install RAID management console only'
	exit 0
}

[ $# -lt 1 ] && usage

distinfo() {
	local issue=/etc/issue
	[ -e /etc/mandrake-release ] && { echo mandrake; return; }
	[ -e /etc/redhat-release ] && { echo redhat; return; }
	[ -e /etc/SuSE-release ] && { echo suse; return; }
	[ -e /etc/debian_version ] && { echo debian; return; }
	[ -e /etc/turbolinux-release ] && { echo turbo; return; }
	if [ -e $issue ]; then
		grep -i debian $issue && { echo debian; return; }
		grep -i "red *hat" $issue && { echo redhat; return; }
		grep -i "suse\|s\.u\.s\.e" $issue && { echo suse; return; }
		grep -i "caldera" $issue && { echo caldera; return; }
	fi
	echo "unknown"
}

confirm() {
	local yorn
	while true; do
		echo -n $1
		read yorn
		[ "$yorn" == "" ] && yorn=$2
		case $yorn in
		[nN])
			return 1;;
		[yY])
			return 0;;
		esac
	done
}

install_service() {
	ps -e|grep hptsvr >/dev/null
	if [ $? -eq 0 ] ; then
		confirm "The service is running. Do you want to stop it? [y]" y ||
	 		{ echo "Installation abored."; exit 1; }
 		`killall  hptsvr` >/dev/null 2>/dev/null
	fi
	if [ ! -f /etc/hptcfg ]; then
		for drv in hptmv hpt374 hpt37x2 hpt370; do
			if [ -d /proc/scsi/$drv ]; then
				echo $drv > /etc/hptcfg
				break
			fi
		done
		if [ ! -f /etc/hptcfg ]; then
			echo "Can't detect any supported driver automatically."
			echo -n "Please specify a driver: [hptmv]"
			read drv
			[ "$drv" == "" ] && drv=hptmv
			echo $drv > /etc/hptcfg
		fi
	fi
	depmod
	cp -f $SRCDIR/hptcliinstall.sh /usr/bin/ && chmod 755 /usr/bin/hptcliinstall.sh
	tar xOzf $SRCPKG $HPTSVR > /usr/bin/hptsvr && chmod 755 /usr/bin/hptsvr
	
	local dist=`distinfo`
	case $dist in
	redhat | mandrake | turbo | caldera)
		tar xOzf $SRCPKG hptdaemon.$dist > /etc/rc.d/init.d/hptdaemon && chmod 755 /etc/rc.d/init.d/hptdaemon
		for level in 3 4 5; do ln -sf /etc/rc.d/init.d/hptdaemon /etc/rc.d/rc${level}.d/S99hptsvr; done
		for level in 1 2 6; do ln -sf /etc/rc.d/init.d/hptdaemon /etc/rc.d/rc${level}.d/K99hptsvr; done
		/etc/rc.d/init.d/hptdaemon start
		;;
	suse)
		tar xOzf $SRCPKG hptdaemon.suse > /etc/init.d/hptdaemon && chmod 755 /etc/init.d/hptdaemon
		for level in 3 4 5; do ln -sf /etc/init.d/hptdaemon /etc/init.d/rc${level}.d/S99hptsvr; done
		for level in 1 2 6; do ln -sf /etc/init.d/hptdaemon /etc/init.d/rc${level}.d/K99hptsvr; done
		/etc/init.d/hptdaemon start
		;;
	debian)
		tar xOzf $SRCPKG hptdaemon.debian > /etc/init.d/hptdaemon && chmod 755 /etc/init.d/hptdaemon
		for level in 3 4 5; do ln -sf /etc/init.d/hptdaemon /etc/rc${level}.d/S99hptsvr; done
		for level in 1 2 6 S; do ln -sf /etc/init.d/hptdaemon /etc/rc${level}.d/K99hptsvr; done
		/etc/init.d/hptdaemon start
		;;
	*)
		echo "Unknown distribution. HighPoint RAID Management Service will not"
		echo "be configured to start automatically. You need to configure it"
		echo "by yourself or start hptsvr manually."
		;;
	esac
}

install_console() {
	ps -e |grep hptraidconf > /dev/null &&
		{ echo "The software (hptraidconf) is running. Please stop it first."; exit 1; }

	cp -f $SRCDIR/hptcliinstall.sh /usr/bin/
	tar xOzf $SRCPKG $HPTRAIDCONF > /usr/bin/hptraidconf && chmod 755 /usr/bin/hptraidconf
	echo "HighPoint RAID Management Console is installed successfully."
}

uninstall() {
	[ -f /usr/bin/hptcliinstall.sh ] ||
		{ echo "The software is not installed."; exit 1; }
	ps -e|grep hptraidconf > /dev/null &&
		{ echo "The software (hptraid) is running. Please stop it first."; exit 1; }
	ps -e |grep  hptsvr > /dev/null &&
		{ echo "The software (hptsvr) is running. Please stop it first."; exit 1; }

	confirm "Are you sure to uninstall HighPoint RAID Management Software? [y/n]" || exit 1

	# uninstall GUI
	if [ -f /usr/bin/hptraidconf ]; then
		rm -fr /usr/bin/hptraidconf
	fi
	
	# uninstall service 
	if [ -f /usr/bin/hptsvr ]; then	
		rm -f /usr/bin/hptsvr /etc/hptcfg /etc/hpt.ini
		rm -f /etc/hptuser.dat /etc/hptmailset.dat /etc/hpttask.dat
		local dist=`distinfo`
		case $dist in
		redhat | mandrake | turbo | caldera)
			rm -f /etc/rc.d/init.d/hptdaemon /etc/rc.d/rc?.d/[SK]99hptsvr
			;;
		suse)
			rm -f /etc/init.d/hptdaemon /etc/init.d/rc?.d/[SK]99hptsvr
			;;
		debian)
			rm -f /etc/init.d/hptdaemon /etc/rc?.d/[SK]99hptsvr
			;;
		esac
	fi
	rm -f /usr/bin/hptcliinstall.sh
	echo "HighPoint RAID Management Console is uninstalled successfully."
}

check_installed() {
	if [ -f /usr/bin/hptcliinstall.sh ]; then
		/usr/bin/hptcliinstall.sh --version > /dev/null ||
			{ echo "You have old version software installed.";
			  echo 'Please uninstall it by "/usr/bin/hptcliinstall.sh -u" before installation.';
			  exit 1; 
			}
		local ver=`/usr/bin/hptcliinstall.sh --version`
		[ "$ver" != "$VERSION" ] &&
			{ echo "You have another version software installed.";
			  echo 'Please uninstall it by "/usr/bin/hptcliinstall.sh -u" before installation.';
			  exit 1; 
			}
	fi
}

check_src() {
	[ -f $SRCPKG ] || { echo "$SRCPKG is missing"; exit 1; }
	local f
	local missing=
	for f in hptraidconf hptsvr \
			hptdaemon.redhat hptdaemon.suse hptdaemon.mandrake \
			hptdaemon.turbo hptdaemon.debian hptdaemon.caldera;
	do
		tar tzf $SRCPKG $f > /dev/null 2>&1 || missing="$missing $f"
	done
	[ "$missing" == "" ] || 
		{ echo "The following source file(s) can't be found:$missing"; exit 1; }
}

case $1 in
-i) 
	check_installed
	check_src
	install_service
	install_console
	;;
-u)
	check_installed
	uninstall
	;;
-s)
	check_installed
	check_src
	install_service
	;;
-g)
	check_installed
	check_src
	install_console
	;;	
-v|--version)
	echo $VERSION
	;;
*)
	usage
	exit 1
	;; 
esac
exit 0
